==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/bg.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Временно хранилището не е налично",
    "Storage invalid" : "Невалидно хранилище",
    "Unknown error" : "Неизвестна грешка",
    "All files" : "Всички файлове",
    "Recent" : "Последни",
    "Favorites" : "Любими",
    "File could not be found" : "Файлът не може да бъде намерен",
    "Move or copy" : "Премести или копирай",
    "Download" : "Изтегли",
    "Delete" : "Изтрий",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Папката \"{dir}\" не може да бъде създадена",
    "Upload cancelled." : "Качването е прекъснато.",
    "…" : "…",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или с размер 0 байта.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място. Опитвате да качите {size1} при свободни само {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Дестинацията \"{dir}\" не съществува",
    "Not enough free space" : "Няма достатъчно свободно място",
    "Uploading …" : "Качване …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} от {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Дестинацията не съществува",
    "Actions" : "Действия",
    "Rename" : "Преименувай",
    "Copy" : "Копирай",
    "Disconnect storage" : "Извади хранилището",
    "Unshare" : "Прекратяване на споделяне",
    "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
    "Files" : "Файлове",
    "Details" : "Детайли",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "This operation is forbidden" : "Операцията е забранена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
    "Could not move \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде преместен, дестинацията съществува",
    "Could not move \"{file}\"" : "Файлът \"{file}\" не може да бъде преместен",
    "Could not copy \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде копиран, дестинацията съществува",
    "Could not copy \"{file}\"" : "Файлът \"{file}\" не може да бъде копиран",
    "{newName} already exists" : "{newName} вече съществува",
    "Could not rename \"{fileName}\", it does not exist any more" : "Файлът \"{fileName}\" не може да бъде преименуван защото не съществува",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" се ползва в директорията \"{dir}\". Моля, изберете друго име.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" не може да бъде преименуван",
    "Could not create file \"{file}\"" : "Файлът \"{file}\" не може да бъде създаден",
    "Could not create file \"{file}\" because it already exists" : "Файлът \"{file}\" не може да бъде създаден защото вече съществува",
    "Could not create folder \"{dir}\" because it already exists" : "Папката \"{dir}\" не може да бъде създадена защото вече съществува",
    "Error deleting file \"{fileName}\"." : "Грешка при изтриването на файла \"{fileName}\".",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Промяна",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включително %n скрит","включително %n скрити"],
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла"],
    "New" : "Създай",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилището на {owner} е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Your storage is full, files can not be updated or synced anymore!" : "Хранилището е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилището на {owner} е почти запълнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашето хранилище е почти запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "View in folder" : "Преглед в папка",
    "Path" : "Път",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "New folder" : "Нова папка",
    "Upload file" : "Качи файл",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "An error occurred while trying to update the tags" : "Възникна грешка при опита за промяна на етикети",
    "Added to favorites" : "Добавено към любимите",
    "Removed from favorites" : "Премахни от любимите",
    "You added {file} to your favorites" : "Добавихте {file} към любимите",
    "You removed {file} from your favorites" : "Премахнахте {file} от любимите",
    "File changes" : "Файлови промени",
    "Created by {user}" : "Създаден от {user}",
    "Changed by {user}" : "Променен от {user}",
    "Deleted by {user}" : "Изтрит от {user}",
    "Restored by {user}" : "Възстановен от {user}",
    "Renamed by {user}" : "Преименуван от {user}",
    "Moved by {user}" : "Преместен от {user}",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "You created {file}" : "Вие създадохте {file}",
    "{user} created {file}" : "{user} създаде {file}",
    "{file} was created in a public folder" : "{file} беше създаден в публична папка",
    "You changed {file}" : "Вие променихте {file}",
    "{user} changed {file}" : "{user} промени {file}",
    "You deleted {file}" : "Вие изтрихте {file}",
    "{user} deleted {file}" : "{user} изтри {file}",
    "You restored {file}" : "Възстановихте {file}",
    "{user} restored {file}" : "{user} възстанови {file}",
    "You renamed {oldfile} to {newfile}" : "Вие преименувахте {oldfile} на {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} преименува {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Вие преместихте {oldfile} в {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} премести {oldfile} в {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл беше добавен или премахнат от <strong>любимите</strong> ви",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "<strong>Промяна</strong> или <strong>преименуване</strong> на файл / папка",
    "A new file or folder has been <strong>created</strong>" : "<strong>Създаване</strong> на нов файл / папка",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Изпращай известия само при създаване / промяна на <strong>любими файлове</strong> <em>(Само за потока)</em>",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "File handling" : "Операция с файла",
    "Maximum upload size" : "Максимален размер",
    "max. possible: " : "максимално:",
    "Save" : "Запиши",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ако ползвате PHP-FPM прилагането на промени може да отнеме 5 минути.",
    "Missing permissions to edit from here." : "Липсва разрешение за редакция от тук.",
    "Settings" : "Настройки",
    "Show hidden files" : "Показвай и скрити файлове",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Адресът осигурява<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">достъп до файловете ви чрез WebDAV</a>",
    "Cancel upload" : "Откажи качването",
    "No files in here" : "Няма файлове",
    "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
    "No favorites yet" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
    "Tags" : "Етикети",
    "Deleted files" : "Изтрити файлове",
    "Shares" : "Споделени",
    "Shared with others" : "Споделени с други",
    "Shared with you" : "Споделени с вас",
    "Shared by link" : "Споделени с връзка",
    "Deleted shares" : "Изтрити",
    "Text file" : "Текстов файл",
    "New text file.txt" : "Текстов файл.txt",
    "Move" : "Премести",
    "Target folder" : "Дестинация",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Адресът осигурява <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">достъп до файловете ви чрез WebDAV</a>"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/bg.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Временно хранилището не е налично",
    "Storage invalid" : "Невалидно хранилище",
    "Unknown error" : "Неизвестна грешка",
    "All files" : "Всички файлове",
    "Recent" : "Последни",
    "Favorites" : "Любими",
    "File could not be found" : "Файлът не може да бъде намерен",
    "Move or copy" : "Премести или копирай",
    "Download" : "Изтегли",
    "Delete" : "Изтрий",
    "Home" : "Домашен",
    "Close" : "Затвори",
    "Could not create folder \"{dir}\"" : "Папката \"{dir}\" не може да бъде създадена",
    "Upload cancelled." : "Качването е прекъснато.",
    "…" : "…",
    "Processing files …" : "Обработване на файлове ...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Неуспешно качване на {filename}, защото е директория или с размер 0 байта.",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Няма достатъчно свободно място. Опитвате да качите {size1} при свободни само {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Дестинацията \"{dir}\" не съществува",
    "Not enough free space" : "Няма достатъчно свободно място",
    "Uploading …" : "Качване …",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} от {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Дестинацията не съществува",
    "Actions" : "Действия",
    "Rename" : "Преименувай",
    "Copy" : "Копирай",
    "Disconnect storage" : "Извади хранилището",
    "Unshare" : "Прекратяване на споделяне",
    "Could not load info for file \"{file}\"" : "Информацията за файла \"{file}\" не може да бъде заредена",
    "Files" : "Файлове",
    "Details" : "Подробности",
    "Select" : "Избери",
    "Pending" : "Чакащо",
    "Unable to determine date" : "Неуспешно установяване на дата",
    "This operation is forbidden" : "Операцията е забранена",
    "This directory is unavailable, please check the logs or contact the administrator" : "Директорията не е налична. Проверете журнала или се свържете с администратора",
    "Could not move \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде преместен, дестинацията съществува",
    "Could not move \"{file}\"" : "Файлът \"{file}\" не може да бъде преместен",
    "Could not copy \"{file}\", target exists" : "Файлът \"{file}\" не може да бъде копиран, дестинацията съществува",
    "Could not copy \"{file}\"" : "Файлът \"{file}\" не може да бъде копиран",
    "{newName} already exists" : "{newName} вече съществува",
    "Could not rename \"{fileName}\", it does not exist any more" : "Файлът \"{fileName}\" не може да бъде преименуван защото не съществува",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Името \"{targetName}\" се ползва в директорията \"{dir}\". Моля, изберете друго име.",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" не може да бъде преименуван",
    "Could not create file \"{file}\"" : "Файлът \"{file}\" не може да бъде създаден",
    "Could not create file \"{file}\" because it already exists" : "Файлът \"{file}\" не може да бъде създаден защото вече съществува",
    "Could not create folder \"{dir}\" because it already exists" : "Папката \"{dir}\" не може да бъде създадена защото вече съществува",
    "Error deleting file \"{fileName}\"." : "Грешка при изтриването на файла \"{fileName}\".",
    "Name" : "Име",
    "Size" : "Размер",
    "Modified" : "Промяна",
    "_%n folder_::_%n folders_" : ["%n папка","%n папки"],
    "_%n file_::_%n files_" : ["%n файл","%n файла"],
    "{dirs} and {files}" : "{dirs} и {files}",
    "_including %n hidden_::_including %n hidden_" : ["включително %n скрит","включително %n скрити"],
    "You don’t have permission to upload or create files here" : "Нямаш разрешение да създаваш или качваш файлове тук.",
    "_Uploading %n file_::_Uploading %n files_" : ["Качване на %n файл","Качване на %n файла"],
    "New" : "Създай",
    "\"{name}\" is an invalid file name." : "\"{name}\" е непозволено име за файл.",
    "File name cannot be empty." : "Името на файла не може да бъде оставено празно.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Хранилището на {owner} е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Your storage is full, files can not be updated or synced anymore!" : "Хранилището е запълнено. Поради това качването и синхронизирането на файлове е невъзможно!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Хранилището на {owner} е почти запълнено ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Вашето хранилище е почти запълнено ({usedSpacePercent}%).",
    "_matches '{filter}'_::_match '{filter}'_" : ["пасва на '{filter}'","пасват на '{filter}'\n "],
    "View in folder" : "Преглед в папка",
    "Path" : "Път",
    "_%n byte_::_%n bytes_" : ["%n байт","%n байта"],
    "Favorited" : "Отбелязано в любими",
    "Favorite" : "Любими",
    "New folder" : "Нова папка",
    "Upload file" : "Качи файл",
    "Remove from favorites" : "Премахни от любимите",
    "Add to favorites" : "Добави към любимите",
    "An error occurred while trying to update the tags" : "Възникна грешка при опита за промяна на етикети",
    "Added to favorites" : "Добавено към любимите",
    "Removed from favorites" : "Премахни от любимите",
    "You added {file} to your favorites" : "Добавихте {file} към любимите",
    "You removed {file} from your favorites" : "Премахнахте {file} от любимите",
    "File changes" : "Файлови промени",
    "Created by {user}" : "Създаден от {user}",
    "Changed by {user}" : "Променен от {user}",
    "Deleted by {user}" : "Изтрит от {user}",
    "Restored by {user}" : "Възстановен от {user}",
    "Renamed by {user}" : "Преименуван от {user}",
    "Moved by {user}" : "Преместен от {user}",
    "\"remote user\"" : "\"отдалечен потребител\"",
    "You created {file}" : "Вие създадохте {file}",
    "{user} created {file}" : "{user} създаде {file}",
    "{file} was created in a public folder" : "{file} беше създаден в публична папка",
    "You changed {file}" : "Вие променихте {file}",
    "{user} changed {file}" : "{user} промени {file}",
    "You deleted {file}" : "Вие изтрихте {file}",
    "{user} deleted {file}" : "{user} изтри {file}",
    "You restored {file}" : "Възстановихте {file}",
    "{user} restored {file}" : "{user} възстанови {file}",
    "You renamed {oldfile} to {newfile}" : "Вие преименувахте {oldfile} на {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} преименува {oldfile} на {newfile}",
    "You moved {oldfile} to {newfile}" : "Вие преместихте {oldfile} в {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} премести {oldfile} в {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Файл беше добавен или премахнат от <strong>любимите</strong> ви",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "<strong>Промяна</strong> или <strong>преименуване</strong> на файл / папка",
    "A new file or folder has been <strong>created</strong>" : "<strong>Създаване</strong> на нов файл / папка",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Изпращай известия само при създаване / промяна на <strong>любими файлове</strong> <em>(Само за потока)</em>",
    "Upload (max. %s)" : "Качи (макс. %s)",
    "File handling" : "Операция с файла",
    "Maximum upload size" : "Максимален размер",
    "max. possible: " : "максимално:",
    "Save" : "Запиши",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Ако ползвате PHP-FPM прилагането на промени може да отнеме 5 минути.",
    "Missing permissions to edit from here." : "Липсва разрешение за редакция от тук.",
    "%1$s of %2$s used" : "%1$s от %2$s използвани",
    "%s used" : "%s използвани",
    "Settings" : "Настройки",
    "Show hidden files" : "Показвай и скрити файлове",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Адресът осигурява<a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">достъп до файловете ви чрез WebDAV</a>",
    "Cancel upload" : "Откажи качването",
    "No files in here" : "Няма файлове",
    "Upload some content or sync with your devices!" : "Качете съдържание или синхронизирайте с вашите устройства!",
    "No entries found in this folder" : "Няма намерени записи в тази папка",
    "Select all" : "Избери всички",
    "Upload too large" : "Прекалено голям файл за качване",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файловете, които се опитвате да качите са по-големи от позволеното на сървъра.",
    "No favorites yet" : "Няма любими",
    "Files and folders you mark as favorite will show up here" : "Файловете и папките които маркирате като любими ще се показват тук",
    "Tags" : "Етикети",
    "Deleted files" : "Изтрити файлове",
    "Shares" : "Споделени",
    "Shared with others" : "Споделени с други",
    "Shared with you" : "Споделени с вас",
    "Shared by link" : "Споделени с връзка",
    "Deleted shares" : "Изтрити",
    "Text file" : "Текстов файл",
    "New text file.txt" : "Текстов файл.txt",
    "Target folder" : "Дестинация",
    "%s of %s used" : "%s от %s използвани"
},
"nplurals=2; plural=(n != 1);");
